@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,7 +32,7 @@ class KPIMTEXTEDIT_EXPORT TextToSpeechConfigInterface : public AbstractTextToSpe
     Q_OBJECT
 public:
     explicit TextToSpeechConfigInterface(QObject *parent = nullptr);
-    ~TextToSpeechConfigInterface();
+    ~TextToSpeechConfigInterface() override;
 
     QVector<QLocale> availableLocales() const override;
     QLocale locale() const override;
